@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -59,6 +60,7 @@
 #include <tools/diagnose_ex.h>
 #include <connectivity/DriversConfig.hxx>
 #include <connectivity/dbtools.hxx>
+#include <sal/macros.h>
 
 #include <boost/optional.hpp>
 
@@ -370,7 +372,7 @@ void ODBExport::exportDataSource()
             };
 
             bool bIsXMLDefault = false;
-            for ( size_t i=0; i < sizeof( aTokens ) / sizeof( aTokens[0] ); ++i )
+            for ( size_t i=0; i < SAL_N_ELEMENTS( aTokens ); ++i )
             {
                 if ( pProperties->Name == aTokens[i].sPropertyName )
                 {
@@ -504,7 +506,7 @@ void ODBExport::exportApplicationConnectionSettings(const TSettingsMap& _aSettin
         ,XML_MAX_ROW_COUNT
         ,XML_SUPPRESS_VERSION_COLUMNS
     };
-    for (size_t i = 0; i< sizeof(pSettings)/sizeof(pSettings[0]); ++i)
+    for (size_t i = 0; i< SAL_N_ELEMENTS(pSettings); ++i)
     {
         TSettingsMap::const_iterator aFind = _aSettings.find(pSettings[i]);
         if ( aFind != _aSettings.end() )
@@ -537,7 +539,7 @@ void ODBExport::exportDriverSettings(const TSettingsMap& _aSettings)
         ,XML_IS_FIRST_ROW_HEADER_LINE
         ,XML_PARAMETER_NAME_SUBSTITUTION
     };
-    for (size_t i = 0; i< sizeof(pSettings)/sizeof(pSettings[0]); ++i)
+    for (size_t i = 0; i< SAL_N_ELEMENTS(pSettings); ++i)
     {
         TSettingsMap::const_iterator aFind = _aSettings.find(pSettings[i]);
         if ( aFind != _aSettings.end() )
@@ -640,7 +642,7 @@ void ODBExport::exportConnectionData()
                         };
 
                         for (   size_t i=0;
-                                i < sizeof( aProperties ) / sizeof( aProperties[0] );
+                                i < SAL_N_ELEMENTS( aProperties );
                                 ++i
                             )
                         {
@@ -1160,7 +1162,7 @@ void ODBExport::exportAutoStyle(XPropertySet* _xProp)
         };
 
         ::std::vector< XMLPropertyState > aPropertyStates;
-        for (size_t i = 0 ; i < sizeof(pExportHelper)/sizeof(pExportHelper[0]); ++i)
+        for (size_t i = 0 ; i < SAL_N_ELEMENTS(pExportHelper); ++i)
         {
             aPropertyStates = pExportHelper[i].first->Filter(_xProp);
             if ( !aPropertyStates.empty() )
@@ -1204,7 +1206,7 @@ void ODBExport::exportAutoStyle(XPropertySet* _xProp)
              TExportPropMapperPair(m_xColumnExportHelper,TEnumMapperPair(&m_aAutoStyleNames,XML_STYLE_FAMILY_TABLE_COLUMN ))
             ,TExportPropMapperPair(m_xCellExportHelper,TEnumMapperPair(&m_aCellAutoStyleNames,XML_STYLE_FAMILY_TABLE_CELL))
         };
-        for (size_t i = 0 ; i < sizeof(pExportHelper)/sizeof(pExportHelper[0]); ++i)
+        for (size_t i = 0 ; i < SAL_N_ELEMENTS(pExportHelper); ++i)
         {
             ::std::vector< XMLPropertyState > aPropStates = pExportHelper[i].first->Filter( _xProp );
             if ( !aPropStates.empty() )
@@ -1453,3 +1455,5 @@ void ODBExport::collectComponentStyles()
 // -----------------------------------------------------------------------------
 }// dbaxml
 // -----------------------------------------------------------------------------
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
