@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -54,7 +55,7 @@
 #include <vcl/svapp.hxx>
 #include <dbaccess/singledoccontroller.hxx>
 #include <svx/unoshape.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
 namespace rptui
 {
@@ -447,3 +448,4 @@ Reference< XPropertySet> OUndoPropertyReportSectionAction::getObject()
 } // rptui
 //============================================================================
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
